//
// Copyright © 2013 Canonical Ltd.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License version 3 as
// published by the Free Software Foundation.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
// Authored by: Mirco Müller <mirco.mueller@canonical.com>
//

#ifndef ACTION_H_
#define ACTION_H_

#include <QObject>
#include <QSharedPointer>
#include <QString>

#include "notification.h"

namespace unity
{
	namespace notifications
	{
		class Notification;

		class Action : public QObject
		{
			Q_OBJECT

			public:
				Q_PROPERTY(QString id READ id NOTIFY idChanged);
				Q_PROPERTY(QString label READ label NOTIFY labelChanged);

				Action(QObject* = 0) : d(new Private())
				{}
				virtual ~Action() {};

				Action(const Action& rhs) = delete;
				Action& operator=(const Action& rhs) = delete;

				virtual QString id() const;
				virtual QString label() const;

				virtual void setId(Type type);
				virtual void setLabel(Type type);

				Q_SIGNAL void idChanged(const QString&);
				Q_SIGNAL void labelChanged(const QString&);

				Q_INVOKABLE virtual void invoke() = 0;
				Q_INVOKABLE virtual QString label() = 0; 
	    
			protected:

			private:
				struct Private
				{
					QString id;
					QString label;
				}* d;

		};
	}
}

#endif // ACTION_H_
